<?php
if ( ! class_exists( 'IPProf_Model' )) {

    /**
     * Class for manage post setting
     */
    class IPProf_Model
    {
        /**
         * Save setting share page
         *
         * @param  int $shareId
         * @return void
         */
        public function save_setting( $profitId )
        {
            $profitId = absint( $profitId );
            $data    = $this->_get_setting_data();
            $setting = new IPProf_Setting( $profitId, '__ipprof-setting' );
            $result  = $setting->setSettings( $data );
            return $result;
        }
        
        /**
         * Get setting data
         *
         * @return array
         */
        protected function _get_setting_data()
        {
            $setting = array();
            $data    = array_merge( $_POST, $_GET );
            
            /*
             * General
             */
            if ( isset( $data['status'] )) {
                $setting['status'] = apply_filters( 'pre_term_name', $data['status'] );
            }
            if ( isset( $data['restricted'] )) {
                $setting['restricted'] = apply_filters( 'pre_term_name', $data['restricted'] );
            }
            if ( isset( $data['per_page'] )) {
                $setting['per_page'] = absint( $data['per_page'] );
            }
            
            /*
             * Header & Footer
             */
            if ( isset( $data['site_header'] )) {
                $setting['site_header'] = apply_filters( 'pre_term_name', $data['site_header'] );
            }
            if ( isset( $data['site_header_text'] )) {
                $setting['site_header_text'] = apply_filters( 'single_post_title', $data['site_header_text'] );
            }
            if ( isset( $data['site_header_image'] )) {
                $setting['site_header_image'] = absint( $data['site_header_image'] );
            }
            if ( isset( $data['header_link'] )) {
                $setting['header_link'] = apply_filters( 'pre_link_url', $data['header_link'] );
            }
            if ( isset( $data['main_menu_status'] )) {
                $setting['main_menu_status'] = apply_filters( 'pre_term_name', $data['main_menu_status'] );
            }
            if ( isset( $data['main_menu'] )) {
                $setting['main_menu'] = absint( $data['main_menu'] );
            }
            if ( isset( $data['footer_text'] )) {
                $setting['footer_text'] = $data['footer_text'];
            }
            if ( isset( $data['footer_menu_status'] )) {
                $setting['footer_menu_status'] = apply_filters( 'pre_term_name', $data['footer_menu_status'] );
            }
            if ( isset( $data['footer_menu'] )) {
                $setting['footer_menu'] = absint( $data['footer_menu'] );
            }
            
            /*
             * Content
             */
            if ( isset( $data['title'] )) {
                $setting['title'] = apply_filters( 'single_post_title', $data['title'] );
            }
            if ( isset( $data['subtitle'] )) {
                $setting['subtitle'] = apply_filters( 'single_post_title', $data['subtitle'] );
            }
            if ( isset( $data['info'] )) {
                $setting['info'] = $data['info'];
            }
            if ( isset( $data['preview_content'] )) {
                $setting['preview_content'] = apply_filters( 'pre_term_name', $data['preview_content'] );
            }
            if ( isset( $data['preview_content_image'] )) {
                $setting['preview_content_image'] = absint( $data['preview_content_image'] );
            }
            if ( isset( $data['preview_content_video'] )) {
                $setting['preview_content_video'] = apply_filters( 'pre_link_url', $data['preview_content_video'] );
            }
            
            /*
             * Design
             */
            if ( isset( $data['header_style'] )) {
                $setting['header_style'] = absint( $data['header_style'] );
            }
            if ( isset( $data['top_bg_color'] )) {
                $setting['top_bg_color'] = apply_filters( 'single_post_title', $data['top_bg_color'] );
            }
            if ( isset( $data['top_text_color'] )) {
                $setting['top_text_color'] = apply_filters( 'single_post_title', $data['top_text_color'] );
            }
            if ( isset( $data['top_menu_style'] )) {
                $setting['top_menu_style'] = apply_filters( 'single_post_title', $data['top_menu_style'] );
            }
            if ( isset( $data['top_menu_color'] )) {
                $setting['top_menu_color'] = apply_filters( 'single_post_title', $data['top_menu_color'] );
            }
            if ( isset( $data['top_font_family'] )) {
                $setting['top_font_family'] = apply_filters( 'pre_term_name', $data['top_font_family'] );
            }
            
            if ( isset( $data['top_content_bg_color'] )) {
                $setting['top_content_bg_color'] = apply_filters( 'single_post_title', $data['top_content_bg_color'] );
            }
            if ( isset( $data['top_content_text_color'] )) {
                $setting['top_content_text_color'] = apply_filters( 'single_post_title', $data['top_content_text_color'] );
            }
            if ( isset( $data['top_content_font_family'] )) {
                $setting['top_content_font_family'] = apply_filters( 'pre_term_name', $data['top_content_font_family'] );
            }
            
            if ( isset( $data['main_bg_color'] )) {
                $setting['main_bg_color'] = apply_filters( 'single_post_title', $data['main_bg_color'] );
            }
            if ( isset( $data['main_text_color'] )) {
                $setting['main_text_color'] = apply_filters( 'single_post_title', $data['main_text_color'] );
            }
            if ( isset( $data['main_font_family'] )) {
                $setting['main_font_family'] = apply_filters( 'pre_term_name', $data['main_font_family'] );
            }
            
            if ( isset( $data['footer_style'] )) {
                $setting['footer_style'] = absint( $data['footer_style'] );
            }
            if ( isset( $data['footer_bg_color'] )) {
                $setting['footer_bg_color'] = apply_filters( 'single_post_title', $data['footer_bg_color'] );
            }
            if ( isset( $data['footer_text_color'] )) {
                $setting['footer_text_color'] = apply_filters( 'single_post_title', $data['footer_text_color'] );
            }
            if ( isset( $data['footer_menu_style'] )) {
                $setting['footer_menu_style'] = apply_filters( 'single_post_title', $data['footer_menu_style'] );
            }
            if ( isset( $data['footer_menu_color'] )) {
                $setting['footer_menu_color'] = apply_filters( 'single_post_title', $data['footer_menu_color'] );
            }
            if ( isset( $data['top_font_family'] )) {
                $setting['footer_font_family'] = apply_filters( 'pre_term_name', $data['footer_font_family'] );
            }
            
            if ( isset( $data['box_style'] )) {
                $setting['box_style'] = absint( $data['box_style'] );
            }
            if ( isset( $data['box_bg_color'] )) {
                $setting['box_bg_color'] = apply_filters( 'single_post_title', $data['box_bg_color'] );
            }
            if ( isset( $data['box_text_color'] )) {
                $setting['box_text_color'] = apply_filters( 'single_post_title', $data['box_text_color'] );
            }
            if ( isset( $data['box_border_status'] )) {
                $setting['box_border_status'] = apply_filters( 'pre_term_name', $data['box_border_status'] );
            }
            if ( isset( $data['box_border_width'] )) {
                $setting['box_border_width'] = absint( $data['box_border_width'] );
            }
            if ( isset( $data['box_border_style'] )) {
                $setting['box_border_style'] = apply_filters( 'pre_term_name', $data['box_border_style'] );
            }
            if ( isset( $data['box_border_color'] )) {
                $setting['box_border_color'] = apply_filters( 'single_post_title', $data['box_border_color'] );
            }
            if ( isset( $data['box_shadow'] )) {
                $setting['box_shadow'] = apply_filters( 'pre_term_name', $data['box_shadow'] );
            }
            if ( isset( $data['box_transparency'] )) {
                $setting['box_transparency'] = absint( $data['box_transparency'] );
            }
            
            /*
             * Share
             */
            if ( isset( $data['share_status'] )) {
                $setting['share_status'] = apply_filters( 'pre_term_name', $data['share_status'] );
            }
            if ( isset( $data['share_facebook'] )) {
                $setting['share_facebook'] = apply_filters( 'pre_term_name', $data['share_facebook'] );
            }
            if ( isset( $data['share_twitter'] )) {
                $setting['share_twitter'] = apply_filters( 'pre_term_name', $data['share_twitter'] );
            }
            if ( isset( $data['share_google-plus'] )) {
                $setting['share_google-plus'] = apply_filters( 'pre_term_name', $data['share_google-plus'] );
            }
            if ( isset( $data['share_pinterest'] )) {
                $setting['share_pinterest'] = apply_filters( 'pre_term_name', $data['share_pinterest'] );
            }
            if ( isset( $data['share_button_icon'] )) {
                $setting['share_button_icon'] = apply_filters( 'pre_term_name', $data['share_button_icon'] );
            }
            
            /*
             * SEO
             */
            if ( isset( $data['meta_title'] )) {
                $setting['meta_title'] = apply_filters( 'single_post_title', $data['meta_title'] );
            }
            if ( isset( $data['meta_description'] )) {
                $setting['meta_description'] = $data['meta_description'];
            }
            if ( isset( $data['meta_keywords'] )) {
                $setting['meta_keywords'] = $data['meta_keywords'];
            }
            if ( isset( $data['ogimage'] )) {
                $setting['ogimage'] = apply_filters( 'pre_link_url', $data['ogimage'] );
            }
            if ( isset( $data['favicon'] )) {
                $setting['favicon'] = apply_filters( 'pre_link_url', $data['favicon'] );
            }
            if ( isset( $data['tracking_code'] )) {
                $setting['tracking_code'] = $data['tracking_code'];
            }
            
            /*
             * Script
             */
            if ( isset( $data['css_code'] )) {
                $setting['css_code'] = $data['css_code'];
            }
            if ( isset( $data['head_js_code'] )) {
                $setting['head_js_code'] = $data['head_js_code'];
            }
            if ( isset( $data['footer_js_code'] )) {
                $setting['footer_js_code'] = $data['footer_js_code'];
            }
            return $setting;
        }
        
        /**
         * Save setting offer item
         *
         * @param  int $offerId
         * @return void
         */
        public function save_offer_setting( $offerId )
        {
            $offerId = absint( $offerId );
            $data    = $this->_get_offer_setting_data();
            $setting = new IPProf_Setting( $offerId, '__ipprof-offer-setting' );
            $result  = $setting->setSettings( $data );
            return $result;
        }
        
        /**
         * Get setting data
         *
         * @return array
         */
        protected function _get_offer_setting_data()
        {
            $setting = array();
            $data    = array_merge( $_POST, $_GET );
            
            if ( isset( $data['offer_status'] )) {
                $setting['offer_status'] = apply_filters( 'pre_term_name', $data['offer_status'] );
            }
            if ( isset( $data['offer_headline'] )) {
                $setting['offer_headline'] = apply_filters( 'single_post_title', $data['offer_headline'] );
            }
            if ( isset( $data['offer_thumbnail_image'] )) {
                $setting['offer_thumbnail_image'] = absint( $data['offer_thumbnail_image'] );
            }
            if ( isset( $data['offer_thumbnail_url'] )) {
                $setting['offer_thumbnail_url'] = apply_filters( 'pre_link_url', $data['offer_thumbnail_url'] );
            }
            if ( isset( $data['offer_info'] )) {
                $setting['offer_info'] = apply_filters( 'single_post_title', $data['offer_info'] );
            }
            if ( isset( $data['offer_action_info'] )) {
                $setting['offer_action_info'] = apply_filters( 'single_post_title', $data['offer_action_info'] );
            }
            if ( isset( $data['offer_url'] )) {
                $setting['offer_url'] = apply_filters( 'pre_link_url', $data['offer_url'] );
            }
            if ( isset( $data['offer_button_label'] )) {
                $setting['offer_button_label'] = apply_filters( 'single_post_title', $data['offer_button_label'] );
            }
            if ( isset( $data['offer_button_style'] )) {
                $setting['offer_button_style'] = apply_filters( 'pre_term_name', $data['offer_button_style'] );
            }
            if ( isset( $data['offer_open'] )) {
                $setting['offer_open'] = apply_filters( 'pre_term_name', $data['offer_open'] );
            }
            
            return $setting;
        }
        
        /**
         * Get stats
         *
         * @return array
         */
        public function get_stats()
        {
            global $wpdb;
            
            $table = $wpdb->prefix . 'ipprof_stats';
            $sql   = "
                SELECT *
                FROM `$table`
            ";
            $results = $wpdb->get_row( $sql );
            return $results;
        }
        
        /**
         * Get stat
         *
         * @param  int $stat_id
         * @return array
         */
        public function get_stat( $stat_id )
        {
            global $wpdb;
            
            $stat_id = absint( $stat_id );
            $table   = $wpdb->prefix . 'ipprof_stats';
            $sql     = "
                SELECT *
                FROM `$table` WHERE stat_id = %d
            ";
            $query   = $wpdb->prepare( $sql, $stat_id );
            $results = $wpdb->get_row( $query );
            return $results;
        }
        
        /**
         * Get stat value
         *
         * @param  int    $page_id
         * @param  string $type
         * @return array
         */
        public function get_stat_value( $page_id, $type )
        {
            $count = 0;
            if ( $stat = $this->get_stat_bypage( $page_id )) {
                if ( isset( $stat->$type )) {
                    $count = (int)$stat->$type;
                }
            }
            return $count;
        }
        
        /**
         * Get stat by page
         *
         * @param  int $page_id
         * @return array
         */
        public function get_stat_bypage( $page_id )
        {
            global $wpdb;
            
            $page_id = absint( $page_id );
            $table   = $wpdb->prefix . 'ipprof_stats';
            $sql     = "
                SELECT 
                    SUM( `stat_view` ) AS `view`,
                    SUM( `stat_click` ) AS `click`
                FROM `$table` WHERE page_id = %d
            ";
            $query   = $wpdb->prepare( $sql, $page_id );
            $results = $wpdb->get_row( $query );
            return $results;
        }
        
        /**
         * Get stat by page date
         *
         * @param  int    $page_id
         * @param  string $date
         * @return array
         */
        public function get_stat_bypage_date( $page_id, $date )
        {
            global $wpdb;
            
            $page_id = absint( $page_id );
            $table   = $wpdb->prefix . 'ipprof_stats';
            $sql     = "
                SELECT *
                FROM `$table` 
                WHERE page_id = $page_id and stat_date = '$date'
            ";
            $results = $wpdb->get_row( $sql );
            return $results;
        }
        
        /**
         * Get statistic data
         *
         * @return array
         */
        public function get_statistic_data( $page_id, $type, $start = null, $end = null )
        {
            global $wpdb;
            
            $page_id = absint( $page_id );
            $table   = $wpdb->prefix . 'ipprof_stats';
            $query   = "
                SELECT 
                    DATE_FORMAT(stat_date, '%Y-%m-%d') AS gdate,";
            //Type value
            if ( $type == 'view' ) {
                $query .= 'SUM(stat_view) AS value';
            } elseif ( $type == 'click' ) {
                $query .= 'SUM(stat_click) AS value';
            } elseif ( $type == 'ctr' ) {
                $query .= 'SUM(stat_view) AS view,';
                $query .= 'SUM(stat_click) AS click';
            } 
            $query .= " FROM $table
                        WHERE page_id = $page_id";
            
            if ( ! empty( $start ) && ! empty( $end )) 
            {
                if ( $start == $end ) {
                    $query .= " AND DATE_FORMAT( stat_date, '%Y-%m-%d' ) = '$start'";
                } else {
                    $query .= " AND stat_date BETWEEN '$start' AND '$end'";
                }
            }
            elseif ( ! empty( $start )) {
                $query .= " AND DATE_FORMAT( stat_date, '%Y-%m-%d' ) = '$start'";
            }
            elseif ( ! empty( $end )) {
                $query .= " AND DATE_FORMAT( stat_date, '%Y-%m-%d' ) = '$end'";
            }
            $query .= " GROUP BY gdate";
            $results = $wpdb->get_results( $query );
            return $results;
        }
        
        /**
         * Do save statistic
         *
         * @param object $page
         * @param string $type
         * @param int    $count
         * @return void
         */
        public function save_stat( $page, $type, $count = 1 )
        {
            $_types = array(
                'view',
                'click'
            );
            $key = 'stat_';
            if ( in_array( $type, $_types )) {
                $key .= $type;
            }
            $date = date( 'Y-m-d 00:00:00' );
            $data = array();
            if ( $stat = $this->get_stat_bypage_date( $page->ID, $date )) 
            {
                $ccount = 0;
                if ( isset( $stat->$key )) {
                    $ccount = $stat->$key;
                }
                $data[$key] = $ccount + $count;
                $this->_update_stat( $stat->stat_id, $data );
            }
            else {
                $data['page_id']   = $page->ID;
                $data['stat_date'] = $date;
                $data[$key]        = $count;
                $this->_insert_stat( $data );
            }
        }
        
        /**
         * Insert statistic data
         *
         * @param array $data
         * @return void
         */
        protected function _insert_stat( $data )
        {
            global $wpdb;
            
            $table  = $wpdb->prefix . 'ipprof_stats';
            $data   = (array)$data;
            
            $result = $wpdb->insert( $table, $data );
            if ( $result ) {
                return $wpdb->insert_id;
            }
            return false;
        }
        
        /**
         * Update statistic data
         *
         * @param int   $id
         * @param array $data
         * @return void
         */
        protected function _update_stat( $id, $data )
        {
            global $wpdb;
            
            $table  = $wpdb->prefix . 'ipprof_stats';
            $data   = (array)$data;
            $where  = array(
                'stat_id' => absint( $id )
            );
            $result = $wpdb->update( $table, $data, $where );
            return $result;
        }
        
        /**
         * Restyle text
         *
         * @param  string $string
         * @return void
         */
        public function restyle_text( $string )
        {
            $string = number_format( $string );
            $string_count = substr_count( $string, ',' );
            if( $string_count != '0' ) {
                if( $string_count == '1'){
                    return substr( $string, 0, -4 ).'K';
                } else if( $string_count == '2' ){
                    return substr( $string, 0, -8 ).'M';
                } else if( $string_count == '3' ){
                    return substr( $string, 0,  -12 ).'B';
                } else {
                    return;
                }
            } else {
                return $string;
            }
        }
    }

}
?>